"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createFileModel = exports.FILE_MODEL_ID = void 0;
var _apiHeadlessCms = require("@webiny/api-headless-cms");
const required = () => {
  return {
    name: "required",
    message: "Value is required."
  };
};
const nameField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Name",
    type: "text",
    validation: [required()]
  });
};
const keyField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Key",
    type: "text",
    validation: [required()]
  });
};
const typeField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Type",
    type: "text",
    validation: [required()]
  });
};
const sizeField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Size",
    type: "number",
    validation: [required()]
  });
};
const metaWidthField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Width",
    type: "number"
  });
};
const metaHeightField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Height",
    type: "number"
  });
};
const metaPrivateField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Private",
    type: "boolean"
  });
};
const metaOriginalKeyField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Original Key",
    type: "text"
  });
};
const metaField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Meta",
    type: "object",
    settings: {
      fields: [metaPrivateField(), metaWidthField(), metaHeightField(), metaOriginalKeyField()]
    }
  });
};
const accessControlTypeField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Type",
    type: "text",
    predefinedValues: {
      enabled: true,
      values: [{
        label: "Public",
        value: "public",
        selected: true
      }, {
        label: "Private",
        value: "private-authenticated"
      }]
    }
  });
};
const accessControlField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Access Control",
    type: "object",
    tags: ["$bulk-edit"],
    settings: {
      fields: [accessControlTypeField()]
    }
  });
};
const tagsField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Tags",
    type: "text",
    tags: ["$bulk-edit"],
    multipleValues: true,
    validation: [required()]
  });
};
const aliasesField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    label: "Aliases",
    type: "text",
    multipleValues: true,
    validation: [required()]
  });
};
const locationField = () => {
  return (0, _apiHeadlessCms.createModelField)({
    type: "object",
    label: "Location",
    fieldId: "location",
    settings: {
      fields: [(0, _apiHeadlessCms.createModelField)({
        type: "text",
        fieldId: "folderId",
        label: "Folder ID",
        settings: {
          path: "location.folderId"
        }
      })]
    }
  });
};
const FILE_MODEL_ID = "fmFile";
exports.FILE_MODEL_ID = FILE_MODEL_ID;
const createFileModel = params => {
  const fields = [locationField(), nameField(), keyField(), typeField(), sizeField(), metaField(), tagsField(), aliasesField()];
  if (params.withPrivateFiles) {
    fields.push(accessControlField());
  }
  return (0, _apiHeadlessCms.createPrivateModel)({
    name: "FmFile",
    modelId: FILE_MODEL_ID,
    titleFieldId: "name",
    authorization: {
      // Disables base permission checks, but leaves FLP checks enabled.
      permissions: false

      // We're leaving FLP enabled (no need to set `flp: true`).
      // flp: true
    },

    fields
  });
};
exports.createFileModel = createFileModel;

//# sourceMappingURL=file.model.js.map