"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSettingsCrud = void 0;
var _pubsub = require("@webiny/pubsub");
var _fields = require("@commodo/fields");
var _validation = require("@webiny/validation");
/**
 * Package @commodo/fields does not have types.
 */ // @ts-expect-error
const CreateDataModel = (0, _fields.withFields)({
  uploadMinFileSize: (0, _fields.number)({
    value: 0,
    validation: _validation.validation.create("gte:0")
  }),
  uploadMaxFileSize: (0, _fields.number)({
    value: 10737418240
  }),
  srcPrefix: (0, _fields.onSet)(value => {
    // Make sure srcPrefix always ends with forward slash.
    if (typeof value === "string") {
      return value.endsWith("/") ? value : value + "/";
    }
    return value;
  })((0, _fields.string)({
    value: "/files/"
  }))
})();
const UpdateDataModel = (0, _fields.withFields)({
  uploadMinFileSize: (0, _fields.number)({
    validation: _validation.validation.create("gte:0")
  }),
  uploadMaxFileSize: (0, _fields.number)(),
  srcPrefix: (0, _fields.onSet)(value => {
    // Make sure srcPrefix always ends with forward slash.
    if (typeof value === "string") {
      return value.endsWith("/") ? value : value + "/";
    }
    return value;
  })((0, _fields.string)())
})();
const createSettingsCrud = ({
  storageOperations,
  getTenantId
}) => {
  return {
    onSettingsBeforeUpdate: (0, _pubsub.createTopic)("fileManager.onSettingsBeforeUpdate"),
    onSettingsAfterUpdate: (0, _pubsub.createTopic)("fileManager.onSettingsAfterUpdate"),
    async getSettings() {
      return storageOperations.settings.get({
        tenant: getTenantId()
      });
    },
    async createSettings(data) {
      const settings = new CreateDataModel().populate(data);
      await settings.validate();
      const settingsData = await settings.toJSON();
      return storageOperations.settings.create({
        data: {
          ...settingsData,
          tenant: getTenantId()
        }
      });
    },
    async updateSettings(data) {
      const updatedValue = new UpdateDataModel().populate(data);
      await updatedValue.validate();
      const existingSettings = await storageOperations.settings.get({
        tenant: getTenantId()
      });
      const updatedSettings = await updatedValue.toJSON({
        onlyDirty: true
      });
      const settings = {
        ...existingSettings,
        ...updatedSettings,
        tenant: getTenantId()
      };
      await this.onSettingsBeforeUpdate.publish({
        input: data,
        original: existingSettings,
        settings
      });
      const result = await storageOperations.settings.update({
        original: existingSettings,
        data: settings
      });
      await this.onSettingsAfterUpdate.publish({
        input: data,
        original: existingSettings,
        settings: result
      });
      return result;
    },
    async deleteSettings() {
      await storageOperations.settings.delete({
        tenant: getTenantId()
      });
      return true;
    }
  };
};
exports.createSettingsCrud = createSettingsCrud;

//# sourceMappingURL=settings.crud.js.map