"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PrivateFileAssetRequestResolver = void 0;
var _ = require("../..");
class PrivateFileAssetRequestResolver {
  constructor(resolver) {
    this.resolver = resolver;
  }
  async resolve(request) {
    // Example: /private/65722cb5c7824a0008d05963/image-48.jpg?width=300
    if (!request.url.startsWith("/private/")) {
      return this.resolver.resolve(request);
    }
    const params = request.params ?? {};
    const query = request.query ?? {};

    // Example: { '*': '/private/65722cb5c7824a0008d05963/image-48.jpg' },
    const path = params["*"];
    return new _.AssetRequest({
      key: decodeURI(path).replace("/private/", ""),
      context: {
        url: request.url,
        private: true
      },
      options: {
        ...query,
        width: query.width ? parseInt(query.width) : undefined
      }
    });
  }
}
exports.PrivateFileAssetRequestResolver = PrivateFileAssetRequestResolver;

//# sourceMappingURL=PrivateFileAssetRequestResolver.js.map