"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createFilesSchema = void 0;
var _handlerGraphql = require("@webiny/handler-graphql");
var _utils = require("./utils");
var _createFilesTypeDefs = require("./createFilesTypeDefs");
var _apiSecurity = require("@webiny/api-security");
const createFilesSchema = params => {
  const fileManagerGraphQL = new _handlerGraphql.GraphQLSchemaPlugin({
    typeDefs: (0, _createFilesTypeDefs.createFilesTypeDefs)(params),
    resolvers: {
      Query: {
        fileManager: _utils.emptyResolver
      },
      Mutation: {
        fileManager: _utils.emptyResolver
      },
      FmFile: {
        async src(file, _, context) {
          const settings = await context.fileManager.getSettings();
          return (settings?.srcPrefix || "") + file.key;
        }
      },
      FmQuery: {
        getFileModel(_, __, context) {
          const identity = context.security.getIdentity();
          if (!identity) {
            return new _apiSecurity.NotAuthorizedResponse();
          }
          return (0, _utils.resolve)(() => context.cms.getModel("fmFile"));
        },
        getFile(_, args, context) {
          return (0, _utils.resolve)(() => context.fileManager.getFile(args.id));
        },
        async listFiles(_, args, context) {
          try {
            const [data, meta] = await context.fileManager.listFiles(args);
            return new _handlerGraphql.ListResponse(data, meta);
          } catch (e) {
            return new _handlerGraphql.ErrorResponse(e);
          }
        },
        async listTags(_, args, context) {
          try {
            const tags = await context.fileManager.listTags(args || {});
            return new _handlerGraphql.Response(tags);
          } catch (error) {
            return new _handlerGraphql.ErrorResponse(error);
          }
        }
      },
      FmMutation: {
        async createFile(_, args, context) {
          return (0, _utils.resolve)(() => {
            return context.fileManager.createFile(args.data, args.meta);
          });
        },
        async createFiles(_, args, context) {
          return (0, _utils.resolve)(() => {
            return context.fileManager.createFilesInBatch(args.data, args.meta);
          });
        },
        async updateFile(_, args, context) {
          return (0, _utils.resolve)(() => {
            return context.fileManager.updateFile(args.id, args.data);
          });
        },
        async deleteFile(_, args, context) {
          return (0, _utils.resolve)(async () => {
            // TODO: Ideally, this should work via a lifecycle hook; first we delete a record from DB, then from cloud storage.
            const file = await context.fileManager.getFile(args.id);
            return await context.fileManager.storage.delete({
              id: file.id,
              key: file.key
            });
          });
        }
      }
    }
  });
  fileManagerGraphQL.name = "fm.graphql.files";
  return fileManagerGraphQL;
};
exports.createFilesSchema = createFilesSchema;

//# sourceMappingURL=filesSchema.js.map