"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createManageFilePlugins = void 0;
var _path = _interopRequireDefault(require("path"));
var _clientS = require("@webiny/aws-sdk/client-s3");
var _utils = require("../utils");
var _imageManager = require("./imageManager");
var _handlerAws = require("@webiny/handler-aws");
const managers = [_imageManager.imageManager];

/**
 * This handler must be run through @webiny/handler-aws/s3
 */
const createManageFilePlugins = () => {
  return [new _handlerAws.S3EventHandler(async ({
    event
  }) => {
    const keys = [];
    for (let i = 0; i < event.Records.length; i++) {
      const record = event.Records[i];
      if (typeof record.s3.object.key === "string") {
        keys.push(record.s3.object.key);
      }
    }
    if (keys.length === 0) {
      return;
    }
    const {
      region
    } = (0, _utils.getEnvironment)();
    const s3 = new _clientS.S3({
      region
    });
    for (const key of keys) {
      const extension = _path.default.extname(key);
      for (const manager of managers) {
        const canProcess = manager.canProcess({
          key,
          extension
        });
        if (!canProcess) {
          continue;
        }
        await manager.process({
          s3,
          key,
          extension
        });
      }
    }
  })];
};
exports.createManageFilePlugins = createManageFilePlugins;

//# sourceMappingURL=index.js.map