"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createFileModelModifier = exports.CmsModelModifierPlugin = void 0;
var _plugins = require("@webiny/plugins");
var _apiHeadlessCms = require("@webiny/api-headless-cms");
var _file = require("../cmsFileStorage/file.model");
class CmsModelFieldsModifier {
  constructor(fields) {
    this.fields = fields;
  }
  addField(field) {
    const {
      bulkEdit,
      tags,
      ...rest
    } = field;
    this.fields.push({
      ...rest,
      tags: (tags ?? []).concat(bulkEdit ? ["$bulk-edit"] : []),
      storageId: `${field.type}@${field.id}`
    });
  }
}
class CmsModelModifierPlugin extends _plugins.Plugin {
  static type = "fm.cms-model-modifier";
  constructor(modelId, cb) {
    super();
    this.modelId = modelId;
    this.cb = cb;
  }
  async modifyModel(model) {
    if (model.modelId !== this.modelId) {
      return;
    }
    let extensionsField = model.fields.find(field => field.fieldId === "extensions");
    if (!extensionsField) {
      extensionsField = (0, _apiHeadlessCms.createModelField)({
        label: "Extensions",
        type: "object",
        settings: {
          layout: [],
          fields: []
        }
      });
      model.fields.push(extensionsField);
    }
    const modifier = new CmsModelFieldsModifier(extensionsField.settings.fields);
    await this.cb({
      modifier
    });
  }
}
exports.CmsModelModifierPlugin = CmsModelModifierPlugin;
const createFileModelModifier = cb => {
  return new CmsModelModifierPlugin(_file.FILE_MODEL_ID, cb);
};
exports.createFileModelModifier = createFileModelModifier;

//# sourceMappingURL=CmsModelModifier.js.map